---
name: 🚀 Feature Request
about: Suggest an idea or improvement
title: "[FEATURE] "
labels: enhancement
---

### Is your feature request related to a problem?
A clear and concise description of the problem.

### Describe the solution you'd like
A clear and concise description of what you want to happen.

### Additional context
Add any other context or screenshots here.